import { schema as credentialsSchema } from '@poppinss/validator-lite';
import { Vault } from './vault.js';
import { Parser } from './parser.js';
import { FileSystem } from './filesystem.js';
import { Validator } from './validator.js';
export class Credentials {
    static #config = {
        path: 'resources/credentials',
        environment: process.env.NODE_ENV || 'development',
        populateEnvironment: false,
    };
    #values;
    constructor(values) {
        this.#values = values;
    }
    static schema = credentialsSchema;
    static rules(schema) {
        const validator = new Validator(schema);
        return validator;
    }
    static async create(schema, config) {
        this.#config = { ...this.#config, ...config };
        const vault = new Vault(this.#config);
        const parser = new Parser();
        const filesystem = new FileSystem();
        const validator = new Validator(schema);
        const key = await vault.getKey();
        const content = await filesystem.read({
            path: `${this.#config.path}/${this.#config.environment}.credentials`,
        });
        const decryptedContent = vault.decrypt({ data: content, key });
        const { data: parsedContent } = parser.parse({ data: decryptedContent });
        const validatedContent = validator.validate({
            data: parsedContent,
        });
        const credentials = new Credentials(validatedContent);
        return credentials;
    }
    get(key, defaultValue) {
        return this.#values[key] ?? defaultValue ?? null;
    }
}
