import { E_CREDENTIALS_INVALID } from './errors.js';
export class Validator {
    #schema;
    constructor(schema) {
        this.#schema = schema;
    }
    validate({ data }) {
        const help = [];
        const validated = Object.keys(this.#schema).reduce((result, key) => {
            const value = process.env[key] || data[key];
            try {
                result[key] = this.#schema[key](key, value);
            }
            catch (error) {
                const updatedMessage = error.message.replace('environment', 'credentials');
                help.push(`- ${updatedMessage}`);
            }
            return result;
        }, { ...data });
        if (help.length) {
            const error = new E_CREDENTIALS_INVALID();
            error.help = help.join('\n');
            throw error;
        }
        return validated;
    }
}
